=======
Credits
=======

Development Lead
----------------
* Caleb Lareau <caleb.lareau@gmail.com>


Code Contributors
------------
* Vincent Liu
* Jeffrey Verboon
* Kopal Garg

Discussants 
------------
* Leif Ludwig
* Jacob Ulirsch
* Martin Aryee
* Jacob Gutierrez 
